<strong>{{ gettext('On %(timestamp)s, %(username)s:', timestamp=h.render_datetime(activity_diff.activities[1].timestamp, with_hours=True, with_seconds=True), username=h.linked_user(activity_diff.activities[1].user_id)) }}</strong>

{% set changes = h.compare_group_dicts(activity_diff.activities[0].data.group, activity_diff.activities[1].data.group, activity_diff.activities[0].id) %}
<ul>
    {% for change in changes %}
        {% snippet "snippets/group_changes/{}.html".format(
            change.type), change=change %}
        <br>
    {% endfor %}
</ul>
