.toolbar {
    .breadcrumb {
        li {
            a {
            }

            &.home {
                i {
                }

                span {
                }
            }

            &.active {
                a {
                }
            }

            // arrow >
            &:before {
            }
        }
    }
}
